==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/lv-LV/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Dienas',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'Pabeidzis aktīvu pārskats.',
    'Expiring_Licenses_Report' => 'Pabeidzamo licenču pārskats.',
    'Item_Request_Canceled' => 'Vienuma pieprasījums atcelts',
    'Item_Requested' => 'Pieprasīts vienums',
    'License_Checkin_Notification' => 'License checked in',
    'License_Checkout_Notification' => 'License checked out',
    'Low_Inventory_Report' => 'Zema inventarizācijas atskaite',
    'a_user_canceled' => 'Lietotājs vietnē ir atcēlis objekta pieprasījumu',
    'a_user_requested' => 'Lietotājs ir pieprasījis vienumu vietnē',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'Piederumu nosaukums:',
    'additional_notes' => 'Papildu piezīmes:',
    'admin_has_created' => 'Administrators ir izveidojis jums kontu: tīmekļa vietnē.',
    'asset' => 'Aktīvs:',
    'asset_name' => 'Aktīvu nosaukums:',
    'asset_requested' => 'Aktīvs pieprasīts',
    'asset_tag' => 'Asset Tag',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Piešķirts',
    'best_regards' => 'Ar laba vēlējumiem,',
    'canceled' => 'Atcelts:',
    'checkin_date' => 'Reģistrēšanās datums:',
    'checkout_date' => 'Izrakstīšanās datums:',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Lūdzu, noklikšķiniet uz saites apakšā, lai apstiprinātu, ka esat saņēmis piederumu.',
    'click_on_the_link_asset' => 'Lūdzu, noklikšķiniet uz saites apakšā, lai apstiprinātu, ka esat saņēmis šo īpašumu.',
    'click_to_confirm' => 'Lūdzu, noklikšķiniet uz šīs saites, lai apstiprinātu savu: tīmekļa kontu:',
    'current_QTY' => 'Pašreizējais QTY',
    'days' => 'Dienas',
    'expecting_checkin_date' => 'Paredzamais reģistrēšanās datums:',
    'expires' => 'Beidzas',
    'hello' => 'Sveiki',
    'hi' => 'Sveiki',
    'i_have_read' => 'Esmu izlasījis un piekrītu lietošanas noteikumiem un saņēmu šo preci.',
    'inventory_report' => 'Inventory Report',
    'item' => 'Vienība:',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Pēc :threshold dienām beigsies termiņš :count licencei.| Pēc :threshold dienām beigsies termiņš :threshold :count licencēm.',
    'link_to_update_password' => 'Lūdzu, noklikšķiniet uz šīs saites, lai atjauninātu savu: web paroli:',
    'login' => 'Pieslēgties:',
    'login_first_admin' => 'Piesakieties savā jaunajā Snipe-IT instalācijā, izmantojot tālāk minētos akreditācijas datus.',
    'low_inventory_alert' => ':count vienības skaits ir zemāks par krājuma minimumu vai drīz būs zems.|:count vienību skaits ir zemāks par krājuma minimumu vai drīz būs zems.',
    'min_QTY' => 'Min QTY',
    'name' => 'Nosaukums',
    'new_item_checked' => 'Jauns objekts ir atzīmēts zem sava vārda, sīkāk ir sniegta zemāk.',
    'notes' => 'Piezīmes',
    'password' => 'Parole:',
    'password_reset' => 'Paroles atiestatīšana',
    'read_the_terms' => 'Lūdzu, izlasiet lietošanas noteikumus zemāk.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'Pieprasīts:',
    'reset_link' => 'Jūsu paroles atiestatīšanas saite',
    'reset_password' => 'Noklikšķiniet šeit, lai atiestatītu savu paroli:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'Sērijas numurs',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Piegādātājs',
    'tag' => 'Tag',
    'test_email' => 'Pārbaudiet e-pastu no Snipe-IT',
    'test_mail_text' => 'Šis ir tests no Snipe-IT Asset Management System. Ja jums ir šis, pasts darbojas :)',
    'the_following_item' => 'Šis ieraksts ir atzīmēts:',
    'to_reset' => 'Lai atiestatītu: tīmekļa paroli, aizpildiet šo veidlapu:',
    'type' => 'Tips',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Lietotājs',
    'username' => 'Lietotājvārds',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Sveicināti: vārds',
    'welcome_to' => 'Laipni lūdzam: tīmeklī!',
    'your_assets' => 'View Your Assets',
    'your_credentials' => 'Jūsu Snipe-IT akreditācijas dati',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/lv-LV/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Dienas',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'Pabeidzis aktīvu pārskats.',
    'Expiring_Licenses_Report' => 'Pabeidzamo licenču pārskats.',
    'Item_Request_Canceled' => 'Vienuma pieprasījums atcelts',
    'Item_Requested' => 'Pieprasīts vienums',
    'License_Checkin_Notification' => 'License checked in',
    'License_Checkout_Notification' => 'License checked out',
    'Low_Inventory_Report' => 'Zema inventarizācijas atskaite',
    'a_user_canceled' => 'Lietotājs vietnē ir atcēlis objekta pieprasījumu',
    'a_user_requested' => 'Lietotājs ir pieprasījis vienumu vietnē',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'Piederuma nosaukums',
    'additional_notes' => 'Papildu piezīmes',
    'admin_has_created' => 'Administrators ir izveidojis jums kontu: tīmekļa vietnē.',
    'asset' => 'Aktīvs',
    'asset_name' => 'Aktīva nosaukums',
    'asset_requested' => 'Aktīvs pieprasīts',
    'asset_tag' => 'Asset Tag',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Piešķirts',
    'best_regards' => 'Ar laba vēlējumiem,',
    'canceled' => 'Atcelts',
    'checkin_date' => 'Reģistrēšanās datums',
    'checkout_date' => 'Izrakstīšanās datums',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Lūdzu, noklikšķiniet uz saites apakšā, lai apstiprinātu, ka esat saņēmis piederumu.',
    'click_on_the_link_asset' => 'Lūdzu, noklikšķiniet uz saites apakšā, lai apstiprinātu, ka esat saņēmis šo īpašumu.',
    'click_to_confirm' => 'Lūdzu, noklikšķiniet uz šīs saites, lai apstiprinātu savu: tīmekļa kontu:',
    'current_QTY' => 'Pašreizējais QTY',
    'days' => 'Dienas',
    'expecting_checkin_date' => 'Paredzamais reģistrēšanās datums',
    'expires' => 'Beidzas',
    'hello' => 'Sveiki',
    'hi' => 'Sveiki',
    'i_have_read' => 'Esmu izlasījis un piekrītu lietošanas noteikumiem un saņēmu šo preci.',
    'inventory_report' => 'Inventory Report',
    'item' => 'Vienums',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Pēc :threshold dienām beigsies termiņš :count licencei.| Pēc :threshold dienām beigsies termiņš :threshold :count licencēm.',
    'link_to_update_password' => 'Lūdzu, noklikšķiniet uz šīs saites, lai atjauninātu savu: web paroli:',
    'login' => 'Pieslēgties:',
    'login_first_admin' => 'Piesakieties savā jaunajā Snipe-IT instalācijā, izmantojot tālāk minētos akreditācijas datus.',
    'low_inventory_alert' => ':count vienības skaits ir zemāks par krājuma minimumu vai drīz būs zems.|:count vienību skaits ir zemāks par krājuma minimumu vai drīz būs zems.',
    'min_QTY' => 'Min QTY',
    'name' => 'Nosaukums',
    'new_item_checked' => 'Jauns objekts ir atzīmēts zem sava vārda, sīkāk ir sniegta zemāk.',
    'notes' => 'Piezīmes',
    'password' => 'Parole',
    'password_reset' => 'Paroles atiestatīšana',
    'read_the_terms' => 'Lūdzu, izlasiet lietošanas noteikumus zemāk.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'Pieprasīts',
    'reset_link' => 'Jūsu paroles atiestatīšanas saite',
    'reset_password' => 'Noklikšķiniet šeit, lai atiestatītu savu paroli:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'Sērijas numurs',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Piegādātājs',
    'tag' => 'Tag',
    'test_email' => 'Pārbaudiet e-pastu no Snipe-IT',
    'test_mail_text' => 'Šis ir tests no Snipe-IT Asset Management System. Ja jums ir šis, pasts darbojas :)',
    'the_following_item' => 'Šis ieraksts ir atzīmēts:',
    'to_reset' => 'Lai atiestatītu: tīmekļa paroli, aizpildiet šo veidlapu:',
    'type' => 'Tips',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Lietotājs',
    'username' => 'Lietotājvārds',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Sveicināti: vārds',
    'welcome_to' => 'Laipni lūdzam: tīmeklī!',
    'your_assets' => 'View Your Assets',
    'your_credentials' => 'Jūsu Snipe-IT akreditācijas dati',
    'mail_sent' => 'Mail sent successfully!',
];
